@@ -19,9 +19,10 @@ from mrivis.base import Collage, SlicePicker
 from visualqc import config as cfg
 from visualqc.image_utils import rescale_without_outliers
 from visualqc.interfaces import BaseReviewInterface
-from visualqc.utils import (check_inputs_defacing, check_out_dir,
-                            compute_cell_extents_grid, pixdim_nifti_header,
-                            read_image, slice_aspect_ratio, check_event_in_axes)
+from visualqc.utils import (check_event_in_axes, check_inputs_defacing,
+                            check_out_dir, compute_cell_extents_grid,
+                            pixdim_nifti_header, read_image, set_fig_window_title,
+                            slice_aspect_ratio)
 from visualqc.workflows import BaseWorkflowVisualQC
 
 
@@ -276,8 +277,8 @@ class DefacingInterface(BaseReviewInterface):
             # notice parentheses at the end
             self.map_key_to_callback[key_pressed]()
         else:
-            if key_pressed in cfg.abbreviation_defacing_default_issue_list:
-                checked_label = cfg.abbreviation_defacing_default_issue_list[
+            if key_pressed in cfg.abbrev_defacing_default_issue_list:
+                checked_label = cfg.abbrev_defacing_default_issue_list[
                     key_pressed]
                 self.checkbox.set_active(
                     cfg.defacing_default_issue_list.index(checked_label))
@@ -299,6 +300,7 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
                  defaced_name,
                  mri_name,
                  render_name,
+                 slice_loc,
                  issue_list=cfg.defacing_default_issue_list,
                  vis_type='defacing'):
         """Constructor"""
@@ -314,13 +316,14 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
         self.defaced_name = defaced_name
         self.mri_name = mri_name
         self.render_name = render_name
+        self.slice_loc = slice_loc
         self.images_for_id = images_for_id
 
         self.expt_id = 'rate_defaced_mri_{}'.format(self.defaced_name)
         self.suffix = self.expt_id
         self.current_alert_msg = None
 
-        self.init_layout()
+        self.init_layout(num_slices_per_view=len(self.slice_loc))
 
         self.__module_type__ = 'defacing'
 
@@ -355,9 +358,8 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
                                bounding_rect=cfg.bbox_defacing_MRI_review,
                                figsize=self.figsize)
         self.fig = self.collage.fig
-        self.fig.canvas.set_window_title('VisualQC defacing : {} {} '
-                                         ''.format(self.in_dir,
-                                                   self.defaced_name))
+        set_fig_window_title(
+            self.fig, f'VisualQC defacing : {self.in_dir} {self.defaced_name} ')
 
         self.padding = padding
 
@@ -403,6 +405,11 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
         self.fig.set_size_inches(self.figsize)
 
 
+    def add_alerts(self):
+        """Brings up an alert if subject id is detected to be an outlier."""
+        pass
+
+
     def load_unit(self, unit_id):
         """Loads the image data for display."""
 
@@ -453,7 +460,7 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
         self.slice_picker = SlicePicker(self.orig_img,
                                         view_set=self.collage.view_set,
                                         num_slices=self.collage.num_slices,
-                                        sampler=cfg.defacing_slice_locations)
+                                        sampler=self.slice_loc)
 
         return skip_subject
 
@@ -553,10 +560,6 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
         raise NotImplementedError()
 
 
-    def add_alerts(self):
-        pass
-
-
     def cleanup(self):
         """Cleanup before exit"""
 
@@ -624,6 +627,14 @@ def get_parser():
     Default: a new folder called ``{}`` will be created inside the input folder
     \n""".format(cfg.default_out_dir_name))
 
+    help_text_slice_locations = textwrap.dedent("""
+    Specifies the locations to slice the MRI volumes at, in percentage of depth
+    from one end to the other i.e. 1 indicates the first non-zero slice in that
+    view (coronal, sagittal etc), 50 would be in the middle, and 100 would be the
+    other end.
+    Default: {}.
+    \n""".format(cfg.defacing_slice_locations))
+
     in_out = parser.add_argument_group('Input and output', ' ')
 
     in_out.add_argument("-u", "--user_dir", action="store", dest="user_dir",
@@ -649,6 +660,12 @@ def get_parser():
     in_out.add_argument("-i", "--id_list", action="store", dest="id_list",
                         default=None, required=False, help=help_text_id_list)
 
+    layout = parser.add_argument_group('Layout options', ' ')
+
+    layout.add_argument("-s", "--slice_locations", action="store", dest="slice_loc",
+                        default=cfg.defacing_slice_locations, required=False,
+                        nargs='+', help=help_text_slice_locations)
+
     return parser
 
 
@@ -670,15 +687,15 @@ def make_workflow_from_user_options():
 
     vis_type = 'defacing'
 
-    user_dir, id_list, images_for_id, defaced_name, mri_name, render_name \
-        = check_inputs_defacing(user_args.user_dir, user_args.defaced_name,
-                                user_args.mri_name, user_args.render_name,
-                                user_args.id_list)
+    user_dir, id_list, images_for_id, defaced_name, mri_name, render_name, \
+        slice_loc = check_inputs_defacing(
+        user_args.user_dir, user_args.defaced_name, user_args.mri_name,
+        user_args.render_name, user_args.id_list, user_args.slice_loc)
 
     out_dir = check_out_dir(user_args.out_dir, user_dir)
 
     wf = RatingWorkflowDefacing(id_list, images_for_id, user_dir, out_dir,
-                                defaced_name, mri_name, render_name,
+                                defaced_name, mri_name, render_name, slice_loc,
                                 cfg.defacing_default_issue_list, vis_type)
 
     return wf
