@@ -10,6 +10,7 @@ import textwrap
 import time
 import warnings
 from abc import ABC
+from os.path import basename, join as pjoin
 from textwrap import wrap
 
 import nibabel as nib
@@ -17,16 +18,15 @@ import numpy as np
 from matplotlib import pyplot as plt
 from matplotlib.widgets import CheckButtons, RadioButtons
 from mrivis.utils import crop_image
-from os.path import basename, join as pjoin
+
 from visualqc import config as cfg
 from visualqc.image_utils import dwi_overlay_edges
 from visualqc.readers import diffusion_traverse_bids
 from visualqc.t1_mri import T1MriInterface
 from visualqc.utils import (check_bids_dir, check_finite_int, check_image_is_4d,
                             check_out_dir, check_outlier_params, check_time,
-                            check_views, get_axis,
-                            pick_slices,
-                            scale_0to1)
+                            check_views, get_axis, pick_slices, scale_0to1,
+                            set_fig_window_title)
 from visualqc.workflows import BaseWorkflowVisualQC
 
 
@@ -264,7 +264,7 @@ class DiffusionMRIInterface(T1MriInterface):
 
 
     def reset_figure(self):
-        "Resets the figure to prepare it for display of next subject."
+        """Resets the figure to prepare it for display of next subject."""
 
         self.zoom_out_callback(None)
         self.restore_axis()
@@ -300,24 +300,6 @@ class DiffusionRatingWorkflow(BaseWorkflowVisualQC, ABC):
                  num_rows_per_view=cfg.default_num_rows_diffusion):
         """
         Constructor.
-
-        Parameters
-        ----------
-        in_dir : path
-            must be a path to BIDS directory
-
-        drop_start : int
-            Number of frames to drop at the beginning of the time series.
-
-        apply_preproc : bool
-            Whether to apply basic preprocessing steps (detrend, slice timing
-            correction etc)
-                before building the carpet image.
-                If the images are already preprocessed elsewhere, disable this
-                with apply_preproc=True
-            Default : False, to not apply any preprocessing before display for
-            review.
-
         """
 
         if id_list is None and 'BIDS' in in_dir_type:
@@ -438,9 +420,8 @@ class DiffusionRatingWorkflow(BaseWorkflowVisualQC, ABC):
 
         # 1. main carpet, in the background
         self.fig, self.ax_carpet = plt.subplots(1, 1, figsize=self.figsize)
-        self.fig.canvas.set_window_title('VisualQC Diffusion MRI :'
-                                         ' {}'.format(self.in_dir))
-
+        set_fig_window_title(
+            self.fig, f'VisualQC Diffusion MRI : {self.in_dir} ')
         self.ax_carpet.set_zorder(self.layer_order_carpet)
         #   vmin/vmax are controlled, because we rescale all to [0, 1]
         self.imshow_params_carpet = dict(interpolation='none', aspect='auto',
@@ -1427,11 +1408,11 @@ def make_workflow_from_user_options():
     num_slices_per_view, num_rows_per_view = check_finite_int(user_args.num_slices,
                                                               user_args.num_rows)
 
-    outlier_method, outlier_fraction, \
-    outlier_feat_types, disable_outlier_detection = check_outlier_params(
-        user_args.outlier_method, user_args.outlier_fraction,
-        user_args.outlier_feat_types, user_args.disable_outlier_detection,
-        id_list, vis_type, type_of_features)
+    outlier_method, outlier_fraction, outlier_feat_types, \
+        disable_outlier_detection = check_outlier_params(
+            user_args.outlier_method, user_args.outlier_fraction,
+            user_args.outlier_feat_types, user_args.disable_outlier_detection,
+            id_list, vis_type, type_of_features)
 
     wf = DiffusionRatingWorkflow(in_dir, out_dir,
                                  id_list=id_list,
