@@ -32,15 +32,13 @@ from visualqc.utils import (check_alpha_set, check_event_in_axes, check_finite_i
                             check_out_dir, check_outlier_params, check_views,
                             freesurfer_vis_tool_installed, get_axis,
                             get_freesurfer_mri_path, get_label_set, pick_slices,
-                            read_image, scale_0to1,
+                            read_image, scale_0to1, set_fig_window_title,
                             void_subcortical_symmetrize_cortical)
 from visualqc.workflows import BaseWorkflowVisualQC
 
-# each rating is a set of labels, join them with a plus delimiter
-_plus_join = lambda label_set: '+'.join(label_set)
-
 next_click = time.monotonic()
 
+
 class FreesurferReviewInterface(BaseReviewInterface):
     """Custom interface for rating the quality of Freesurfer parcellation."""
 
@@ -129,7 +127,7 @@ class FreesurferReviewInterface(BaseReviewInterface):
 
 
     def reset_figure(self):
-        "Resets the figure to prepare it for display of next subject."
+        """Resets the figure to prepare it for display of next subject."""
 
         self.clear_data()
         self.clear_radio_buttons()
@@ -185,8 +183,8 @@ class FreesurferReviewInterface(BaseReviewInterface):
             self.toggle_overlay()
 
         # double click to zoom in to that axis
-        elif ((double_clicked) and \
-              (event.inaxes is not None) and \
+        elif (double_clicked and
+              (event.inaxes is not None) and
               (not check_event_in_axes(event, self.unzoomable_axes))):
             # click_type = 'DOUBLE'
             # zoom axes full-screen
@@ -202,7 +200,7 @@ class FreesurferReviewInterface(BaseReviewInterface):
         else:
             # click_type = 'SINGLE/other'
             # unzoom any zoomed-in axis in case of a mouse event
-            if (self.prev_axis is not None):
+            if self.prev_axis is not None:
                 # include all the non-data axes here (so they wont be zoomed-in)
                 if not check_event_in_axes(event, self.unzoomable_axes):
                     self.prev_axis.set_position(self.prev_ax_pos)
@@ -348,9 +346,6 @@ class FreesurferRatingWorkflow(BaseWorkflowVisualQC, ABC):
         print('\nAttempting to generate surface visualizations of parcellation ...')
         self._freesurfer_installed, self._fs_vis_tool = \
             freesurfer_vis_tool_installed()
-        if not self._freesurfer_installed:
-            print('Freesurfer does not seem to be installed '
-                  '- skipping surface visualizations.')
 
         self.surface_vis_paths = dict()
         for sid in self.id_list:
@@ -410,8 +405,9 @@ class FreesurferRatingWorkflow(BaseWorkflowVisualQC, ABC):
         self.fig, self.axes = plt.subplots(self.num_rows_total, self.num_cols_final,
                                            figsize=self.figsize)
         self.axes = self.axes.flatten()
-        self.fig.canvas.set_window_title('VisualQC {} {} : {}'
-                                         ' '.format(self.vis_type, self.seg_name, self.in_dir))
+        set_fig_window_title(self.fig,
+                             'VisualQC {} {} : {} '
+                             ''.format(self.vis_type, self.seg_name, self.in_dir))
 
         self.display_params_mri = dict(interpolation='none', aspect='equal',
                                        origin='lower',
@@ -527,16 +523,17 @@ class FreesurferRatingWorkflow(BaseWorkflowVisualQC, ABC):
     def update_histogram(self):
         """Updates histogram with current image data"""
 
-        # to update thickness histogram, you need access to full FS output or aparc.stats
+        # to update thickness histogram, we need access to full FS output/aparc.stats
         try:
-            distribution_to_show = read_aparc_stats_wholebrain(self.in_dir, self.current_unit_id,
-                                                   subset=(cfg.statistic_in_histogram_freesurfer,))
+            distrib_to_show = read_aparc_stats_wholebrain(
+                self.in_dir, self.current_unit_id,
+                subset=(cfg.statistic_in_histogram_freesurfer,))
         except:
             # do nothing
             return
 
-        # number of vertices is too high - so presenting mean ROI thickness is smarter!
-        _, _, patches_hist = self.ax_hist.hist(distribution_to_show, density=True,
+        # number of vertices is too high so presenting mean ROI thickness is smarter!
+        _, _, patches_hist = self.ax_hist.hist(distrib_to_show, density=True,
                                                bins=cfg.num_bins_histogram_display)
         self.ax_hist.set_xlim(cfg.xlim_histogram_freesurfer)
         self.ax_hist.relim(visible_only=True)
@@ -562,8 +559,8 @@ class FreesurferRatingWorkflow(BaseWorkflowVisualQC, ABC):
         if flagged_as_outlier:
             alerts_list = self.by_sample.get(self.current_unit_id,
                                              None)  # None, if id not in dict
-            print('\n\tFlagged as a possible outlier by these measures:\n\t\t{}'.format(
-                '\t'.join(alerts_list)))
+            print('\n\tFlagged as a possible outlier by these measures:\n\t\t{}'
+                  ''.format('\t'.join(alerts_list)))
 
             strings_to_show = ['Flagged as an outlier:', ] + alerts_list
             self.current_alert_msg = '\n'.join(strings_to_show)
@@ -583,13 +580,13 @@ class FreesurferRatingWorkflow(BaseWorkflowVisualQC, ABC):
 
         if temp_t1_mri.shape != temp_fs_seg.shape:
             raise ValueError('size mismatch! MRI: {} Seg: {}\n'
-                             'Size must match in all dimensions.'.format(
-                self.current_t1_mri.shape,
-                temp_fs_seg.shape))
+                             'Size must match in all dimensions.'
+                             ''.format(temp_t1_mri.shape, temp_fs_seg.shape))
 
         skip_subject = False
         if self.vis_type in ('cortical_volumetric', 'cortical_contour'):
-            temp_seg_uncropped, roi_set_is_empty = void_subcortical_symmetrize_cortical(temp_fs_seg)
+            temp_seg_uncropped, roi_set_is_empty = \
+                void_subcortical_symmetrize_cortical(temp_fs_seg)
         elif self.vis_type in ('labels_volumetric', 'labels_contour'):
             if self.label_set is not None:
                 # TODO same colors for same labels is not guaranteed
@@ -598,7 +595,7 @@ class FreesurferRatingWorkflow(BaseWorkflowVisualQC, ABC):
                 temp_seg_uncropped, roi_set_is_empty = get_label_set(temp_fs_seg,
                                                                      self.label_set)
             else:
-                raise ValueError('--label_set must be specified for visualization types: '
+                raise ValueError('--label_set must be specified for vis types: '
                                  ' labels_volumetric and labels_contour')
         else:
             raise NotImplementedError('Invalid visualization type - '
@@ -704,7 +701,7 @@ class FreesurferRatingWorkflow(BaseWorkflowVisualQC, ABC):
         plt.close('all')
 
 
-def make_vis_pial_surface(fs_dir, subject_id, out_dir,
+def make_vis_pial_surface(fs_dir, subj_id, out_dir,
                           FREESURFER_INSTALLED,
                           annot_file='aparc.annot',
                           vis_tool=cfg.freesurfer_vis_cmd):
@@ -718,59 +715,86 @@ def make_vis_pial_surface(fs_dir, subject_id, out_dir,
     hemis_long = ('left', 'right')
     vis_list = dict()
 
-    print('Processing {}'.format(subject_id))
+    print('Processing {}'.format(subj_id))
     for hemi, hemi_l in zip(hemis, hemis_long):
 
-        # generating necessary scripts
         vis_list[hemi_l] = dict()
-        if vis_tool == "freeview":
-            script_file, vis_files = make_freeview_script_vis_annot(
-                fs_dir, subject_id, hemi, out_vis_dir, annot_file)
-        elif vis_tool == "tksurfer":
-            script_file, vis_files = make_tcl_script_vis_annot(
-                subject_id, hemi_l, out_vis_dir, annot_file)
-        else:
-            pass
+        vis_list[hemi_l] = make_vis_paths(subj_id, hemi, out_vis_dir, vis_tool)
+        all_vis_exist = all([vp.exists() for vp in vis_list[hemi_l].values()])
+        if not all_vis_exist:
+            # generating necessary scripts
+            if vis_tool == "freeview":
+                script_file, vis_files = make_freeview_script_vis_annot(
+                    fs_dir, subj_id, hemi, out_vis_dir, annot_file)
+            elif vis_tool == "tksurfer":
+                script_file, vis_files = make_tcl_script_vis_annot(
+                    subj_id, hemi_l, out_vis_dir, annot_file)
+            else: # when freesurfer is not installed or not in path
+                vis_files = make_vis_paths(subj_id, hemi, out_vis_dir)
 
-        # not running the scripts if required files dont exist
-        surf_path = fs_dir / subject_id / 'surf' / '{}.pial'.format(hemi)
-        annot_path = fs_dir / subject_id / 'label' / '{}.{}'.format(hemi, annot_file)
-        if not surf_path.exists():
-            print(f"surface for {subject_id} {hemi_l} doesn't exist @\n {surf_path}")
-            continue
-        if not annot_path.exists():
-            print(f"Annot for {subject_id} {hemi_l} doesn't exist @\n{annot_path}")
-            continue
+            # not running the scripts if required files don't exist
+            surf_path = fs_dir / subj_id / 'surf' / f'{hemi}.pial'
+            annot_path = fs_dir / subj_id / 'label' / f'{hemi}.{annot_file}'
 
-        try:
-            # run the script only if all the visualizations were not generated before
-            all_vis_exist = all([vp.exists() for vp in vis_files.values()])
-            if not all_vis_exist and FREESURFER_INSTALLED:
-                if vis_tool == "freeview":
-                    _, _ = run_freeview_script(script_file)
-                elif vis_tool == "tksurfer":
-                    _, _ = run_tksurfer_script(fs_dir, subject_id, hemi, script_file)
-                else:
-                    pass
+            if surf_path.exists() and annot_path.exists():
+                try:
+                    # run script only if all vis were not generated before
+                    if FREESURFER_INSTALLED:
+                        if vis_tool == "freeview":
+                            _, _ = run_freeview_script(script_file)
+                        elif vis_tool == "tksurfer":
+                            _, _ = run_tksurfer_script(fs_dir, subj_id, hemi, script_file)
+                        else:
+                            pass
 
-            vis_list[hemi_l].update(vis_files)
-        except:
-            traceback.print_exc()
-            print(f'unable to generate 3D surf vis for {hemi} hemi - skipping')
+                    vis_list[hemi_l].update(vis_files)
+                except:
+                    traceback.print_exc()
+                    print(f'unable to generate 3D surf vis for {hemi} hemi. '
+                          f'skipping')
+            else:
+                if not surf_path.exists():
+                    print(f"surface for {subj_id} {hemi_l} doesn't exist @"
+                          f"\n {surf_path}")
+                if not annot_path.exists():
+                    print(f"Annot for {subj_id} {hemi_l} doesn't exist @"
+                          f"\n{annot_path}")
 
-    # flattening it for easier use later on
+    # flattening / reordering it for easier use later on
     out_vis_list = dict()
     for hemi_l, view in cfg.view_pref_order[vis_tool]:
         try:
             if vis_list[hemi_l][view].exists():
                 out_vis_list[(hemi_l, view)] = vis_list[hemi_l][view]
+            else:
+                print(f'no surf vis for {subj_id} {hemi_l} {view}')
         except:
-            # not file hemi/view combinations have files generated
+            # not all hemi/view combinations have vis files generated
             pass
 
     return out_vis_list
 
 
+def make_vis_paths(subject_id, hemi, out_vis_dir, vis_tool='freeview'):
+    """util to make output paths to store visualizations"""
+
+    vis_path = dict()
+    vis_tool = vis_tool.lower()
+    if vis_tool == 'freeview':
+        img_ext = 'png'
+        angles = cfg.freeview_surface_vis_angles
+    elif vis_tool == 'tksurfer':
+        img_ext = 'tif'
+        angles = cfg.tksurfer_surface_vis_angles
+    else:
+        raise ValueError('Invalid vis_tool, it must be freeview or tksurfer')
+
+    for view in angles:
+        vis_path[view] = out_vis_dir / f'{subject_id}_{hemi}_{view}.{img_ext}'
+
+    return vis_path
+
+
 def make_freeview_script_vis_annot(fs_dir, subject_id, hemi, out_vis_dir,
                                    annot_file='aparc.annot'):
     """Generates a tksurfer script to make visualizations"""
@@ -778,13 +802,12 @@ def make_freeview_script_vis_annot(fs_dir, subject_id, hemi, out_vis_dir,
     fs_dir = Path(fs_dir).resolve()
     out_vis_dir = Path(out_vis_dir).resolve()
 
+    vis_path = make_vis_paths(subject_id, hemi, out_vis_dir, vis_tool='freeview')
+
     surf_path = fs_dir / subject_id / 'surf' / '{}.pial'.format(hemi)
     annot_path = fs_dir / subject_id / 'label' / '{}.{}'.format(hemi, annot_file)
 
     script_file = out_vis_dir / 'vis_annot_{}.freeview.cmd'.format(hemi)
-    vis_path = dict()
-    for view in cfg.freeview_surface_vis_angles:
-        vis_path[view] = out_vis_dir / '{}_{}_{}.png'.format(subject_id, hemi, view)
 
     # NOTES reg freeview commands
     # --screenshot <FILENAME> <MAGIFICATION_FACTOR> <AUTO_TRIM>
@@ -814,10 +837,7 @@ def make_freeview_script_vis_annot(fs_dir, subject_id, hemi, out_vis_dir,
 def make_tcl_script_vis_annot(subject_id, hemi, out_vis_dir, annot_file='aparc.annot'):
     """Generates a tksurfer script to make visualizations"""
 
-    script_file = out_vis_dir / f'vis_annot_{hemi}.tcl'
-    vis = dict()
-    for view in cfg.tksurfer_surface_vis_angles:
-        vis[view] = out_vis_dir / f'{subject_id}_{hemi}_{view}.tif'
+    vis_path = make_vis_paths(subject_id, hemi, out_vis_dir, vis_tool='tksurfer')
 
     img_format = 'tiff'  # rgb does not work
 
@@ -826,23 +846,24 @@ def make_tcl_script_vis_annot(subject_id, hemi, out_vis_dir, annot_file='aparc.a
     cmds.append("labl_import_annotation {}".format(annot_file))
     cmds.append("scale_brain 1.37")
     cmds.append("redraw")
-    cmds.append("save_{} {}".format(img_format, vis['lateral']))
+    cmds.append("save_{} {}".format(img_format, vis_path['lateral']))
     cmds.append("rotate_brain_y 180.0")
     cmds.append("redraw")
-    cmds.append("save_{} {}".format(img_format, vis['medial']))
+    cmds.append("save_{} {}".format(img_format, vis_path['medial']))
     cmds.append("rotate_brain_z -90.0")
     cmds.append("rotate_brain_y 135.0")
     cmds.append("redraw")
-    cmds.append("save_{} {}".format(img_format, vis['transverse']))
+    cmds.append("save_{} {}".format(img_format, vis_path['transverse']))
     cmds.append("exit 0")
 
+    script_file = out_vis_dir / f'vis_annot_{hemi}.tcl'
     try:
         with open(script_file, 'w') as sf:
             sf.write('\n'.join(cmds))
     except:
         raise IOError('Unable to write the script file to\n {}'.format(script_file))
 
-    return script_file, vis
+    return script_file, vis_path
 
 
 def run_tksurfer_script(fs_dir, subject_id, hemi, script_file):
@@ -851,7 +872,8 @@ def run_tksurfer_script(fs_dir, subject_id, hemi, script_file):
     try:
         cmd_args = ['tksurfer', '-sdir', fs_dir, subject_id, hemi, 'pial',
                     '-tcl', script_file]
-        txt_out = check_output(cmd_args, shell=False, stderr=subprocess.STDOUT, universal_newlines=True)
+        txt_out = check_output(cmd_args, shell=False, stderr=subprocess.STDOUT,
+                               universal_newlines=True)
     except subprocess.CalledProcessError as tksurfer_exc:
         exit_code = tksurfer_exc.returncode
         txt_out = tksurfer_exc.output
@@ -868,7 +890,8 @@ def run_freeview_script(script_file):
 
     try:
         cmd_args = ['freeview', '--command', script_file]
-        txt_out = check_output(cmd_args, shell=False, stderr=subprocess.STDOUT, universal_newlines=True)
+        txt_out = check_output(cmd_args, shell=False, stderr=subprocess.STDOUT,
+                               universal_newlines=True)
     except subprocess.CalledProcessError as tksurfer_exc:
         exit_code = tksurfer_exc.returncode
         txt_out = tksurfer_exc.output
@@ -889,7 +912,7 @@ def get_parser():
                                                  'of Freesurfer reconstruction.')
 
     help_text_fs_dir = textwrap.dedent("""
-    Absolute path to ``SUBJECTS_DIR`` containing the finished runs of Freesurfer parcellation
+    Absolute path to ``SUBJECTS_DIR`` containing the finished Freesurfer processing.
     Each subject will be queried after its ID in the metadata file.
 
     E.g. ``--fs_dir /project/freesurfer_v5.3``
@@ -937,24 +960,26 @@ def get_parser():
     \n""".format(cfg.default_vis_type))
 
     help_text_label = textwrap.dedent("""
-    Specifies the set of labels to include for overlay.
-
-    Atleast one label must be specified when vis_type is labels_volumetric or labels_contour
+    Specifies the set of labels to include for overlay. Atleast one label must be
+    specified when vis_type is labels_volumetric or labels_contour
 
     Default: None (show nothing)
     \n""")
 
     help_text_contour_color = textwrap.dedent("""
-    Specifies the color to use for the contours overlaid on MRI (when vis_type requested prescribes contours).
-    Color can be specified in many ways as documented in https://matplotlib.org/users/colors.html
+    Specifies the color to use for the contours overlaid on MRI, when vis_type
+      requested prescribes contours). Color can be specified in many ways
+      as documented in https://matplotlib.org/users/colors.html
     Default: {}.
     \n""".format(cfg.default_contour_face_color))
 
     help_text_alphas = textwrap.dedent("""
     Alpha values to control the transparency of MRI and aseg.
-    This must be a set of two values (between 0 and 1.0) separated by a space e.g. --alphas 0.7 0.5.
+    This must be a set of two values (between 0 and 1.0) separated by a space
+    e.g. --alphas 0.7 0.5.
 
-    Default: {} {}.  Play with these values to find something that works for you and the dataset.
+    Default: {} {}.
+    Play with these values to find something that works for you and the dataset.
     \n""".format(cfg.default_alpha_mri, cfg.default_alpha_seg))
 
     help_text_views = textwrap.dedent("""
@@ -975,9 +1000,13 @@ def get_parser():
     \n""".format(cfg.default_num_rows))
 
     help_text_no_surface_vis = textwrap.dedent("""
-    This flag disables batch-generation of 3d surface visualizations, which are shown along with cross-sectional overlays. This is not recommended, but could be used in situations where you do not have Freesurfer installed or want to focus solely on cross-sectional views.
+    This flag disables batch-generation of 3d surface visualizations, which are shown
+    along with cross-sectional overlays. This is not recommended, but could be used
+    in situations where you do not have Freesurfer installed, or want to focus
+    solely on cross-sectional views.
 
-    Default: False (required visualizations are generated at the beginning, which can take 5-10 seconds for each subject).
+    Default: False (required visualizations are generated at the beginning,
+        which can take 5-10 seconds for each subject).
     \n""")
 
     help_text_outlier_detection_method = textwrap.dedent("""
@@ -1054,7 +1083,8 @@ def get_parser():
                           required=False, help=help_text_alphas)
 
     outliers = parser.add_argument_group('Outlier detection',
-                                         'options related to automatically detecting possible outliers')
+                                         'options related to automatically detecting '
+                                         'possible outliers')
     outliers.add_argument("-olm", "--outlier_method", action="store",
                           dest="outlier_method",
                           default=cfg.default_outlier_detection_method, required=False,
@@ -1087,9 +1117,10 @@ def get_parser():
                         default=cfg.default_num_rows, required=False,
                         help=help_text_num_rows)
 
-    wf_args = parser.add_argument_group('Workflow', 'Options related to workflow '
-                                                    'e.g. to pre-compute resource-intensive features, '
-                                                    'and pre-generate all the visualizations required')
+    wf_args = parser.add_argument_group(
+        'Workflow', 'Options related to workflow e.g. to pre-compute '
+                    'resource-intensive features, and pre-generate all the '
+                    'visualizations required')
 
     wf_args.add_argument("-ns", "--no_surface_vis", action="store_true",
                          dest="no_surface_vis", help=help_text_no_surface_vis)
