@@ -21,11 +21,10 @@ from visualqc import config as cfg
 from visualqc.image_utils import mask_image
 from visualqc.readers import func_mri_traverse_bids
 from visualqc.t1_mri import T1MriInterface
-from visualqc.utils import (check_bids_dir, check_finite_int,
-                            check_id_list_with_regex,
-                            check_image_is_4d, check_out_dir, check_outlier_params,
-                            check_views, get_axis,
-                            pick_slices, scale_0to1)
+from visualqc.utils import (check_bids_dir, check_event_in_axes, check_finite_int,
+                            check_id_list_with_regex, check_image_is_4d,
+                            check_out_dir, check_outlier_params, check_views,
+                            get_axis, pick_slices, scale_0to1, set_fig_window_title)
 from visualqc.workflows import BaseWorkflowVisualQC
 
 
@@ -43,8 +42,6 @@ def _unbidsify(filename, max_width=18):
 
     return '\n'.join(fixed_width)
 
-_z_score = lambda x: (x - np.mean(x)) / np.std(x)
-
 
 class FunctionalMRIInterface(T1MriInterface):
     """Interface for the review of fMRI images."""
@@ -91,16 +88,18 @@ class FunctionalMRIInterface(T1MriInterface):
 
         self.add_checkboxes()
 
+        self.unzoomable_axes = [self.checkbox.ax, self.text_box.ax,
+                                self.bt_next.ax, self.bt_quit.ax]
+
         # this list of artists to be populated later
         # makes to handy to clean them all
         self.data_handles = list()
 
 
     def add_checkboxes(self):
-        """
-        Checkboxes offer the ability to select multiple tags such as Motion, Ghosting Aliasing etc,
-            instead of one from a list of mutual exclusive rating options (such as Good, Bad, Error etc).
-
+        """Checkboxes offer the ability to select multiple tags such as Motion,
+        Ghosting Aliasing etc, instead of one from a list of mutual exclusive
+        rating options (such as Good, Bad, Error etc).
         """
 
         ax_checkbox = plt.axes(cfg.position_checkbox, facecolor=cfg.color_rating_axis)
@@ -150,16 +149,14 @@ class FunctionalMRIInterface(T1MriInterface):
         """Callback for mouse events."""
 
         # if event occurs in non-data areas, do nothing
-        if event.inaxes in [self.checkbox.ax, self.text_box.ax,
-                            self.bt_next.ax, self.bt_quit.ax]:
+        if check_event_in_axes(event, self.unzoomable_axes):
             return
 
         if self.zoomed_in:
-            # include all the non-data axes here (so they wont be zoomed-in)
-            if event.inaxes not in [self.checkbox.ax, self.text_box.ax,
-                                    self.bt_next.ax, self.bt_quit.ax]:
-                if event.dblclick or event.button in [3]:
-                    if event.inaxes in self.axes_to_zoom:
+            # include all the non-data axes here (so they won't be zoomed-in)
+            if not check_event_in_axes(event, self.unzoomable_axes):
+                if event.dblclick or (event.button in [3]):
+                    if check_event_in_axes(event, self.axes_to_zoom):
                         self.maximize_axis(event.inaxes)
                     else:
                         self.zoom_out_callback(event)
@@ -396,8 +393,7 @@ class FmriRatingWorkflow(BaseWorkflowVisualQC, ABC):
 
         # 1. main carpet, in the background
         self.fig, self.ax_carpet = plt.subplots(1, 1, figsize=self.figsize)
-        self.fig.canvas.set_window_title('VisualQC Functional MRI :'
-                                         ' {}'.format(self.in_dir))
+        set_fig_window_title(self.fig, f'VisualQC Functional MRI : {self.in_dir}')
 
         self.ax_carpet.set_zorder(self.layer_order_carpet)
         #   vmin/vmax are controlled, because we rescale all to [0, 1]
@@ -577,7 +573,7 @@ class FmriRatingWorkflow(BaseWorkflowVisualQC, ABC):
         # TODO should we perform head motion correction before any display at all?
         # TODO what about slice timing correction?
 
-        #num_voxels = np.prod(self.img_this_unit.shape[0:3])
+        # num_voxels = np.prod(self.img_this_unit.shape[0:3])
         num_time_points = self.img_this_unit.shape[3]
         time_points = list(range(num_time_points))
 
@@ -810,8 +806,8 @@ def compute_DVARS(func_img, mean_img=None, mask=None, apply_mask=False):
     num_time_points = func_img.shape[3]
 
     RMS_diff = lambda img2, img1: np.sqrt(np.mean(np.square(img2 - img1)))
-    DVARS_1_to_N = [RMS_diff(func_img[:, :, :, t], func_img[:, :, :, t - 1]) for t in
-                    range(1, num_time_points)]
+    DVARS_1_to_N = [RMS_diff(func_img[:, :, :, t], func_img[:, :, :, t - 1])
+                    for t in range(1, num_time_points)]
 
     DVARS = np.full(num_time_points, np.nan)
     # dvars value at time point 0 is set to 0
@@ -831,7 +827,10 @@ def temporal_stats(func_img):
 
 
 def spatial_stats(func_img):
-    """Computes volume-wise spatial average of functional data --> single vector over time."""
+    """
+    Computes volume-wise spatial average of functional data
+         --> single vector over time.
+     """
 
     num_time_points = func_img.shape[3]
     mean_signal = np.array(
@@ -851,7 +850,7 @@ def _rescale_over_time(matrix):
 
     if matrix.shape[0] <= matrix.shape[1]:
         raise ValueError('Number of voxels is less than the number of time points!! '
-                      'Are you sure data is reshaped correctly?')
+                         'Are you sure data is reshaped correctly?')
 
     min_ = matrix.min(axis=1)
     range_ = matrix.ptp(axis=1)  # ptp : peak to peak, max-min
