@@ -67,6 +67,15 @@ def pixdim_nifti_header(header):
     return header['pixdim'][1:4]
 
 
+def set_fig_window_title(fig, text):
+    """Sets the title of the given figure"""
+
+    try:
+        fig.canvas.manager.set_window_title(text)
+    except:  # not all backends support this, so quietly ignoring it
+        pass
+
+
 def slice_aspect_ratio(pixel_dim, axis):
     """computes aspect ratio for the cross-sectional slices of a given dimension"""
 
@@ -187,7 +196,8 @@ def get_axis(array, axis, slice_num):
     # Using a non-tuple sequence for multidimensional indexing is deprecated;
     #   use `arr[tuple(seq)]` instead of `arr[seq]`.
     # In the future this will be interpreted as an array index,
-    #   `arr[np.array(seq)]`, which will result either in an error or a different result.
+    #   `arr[np.array(seq)]`, which will result either in an error or a different
+    #   result.
     slice_data = array[tuple(slice_list)].T  # for proper appearance
 
     return slice_data
@@ -221,9 +231,10 @@ def pick_slices(img, view_set, num_slices):
         slices_in_dim = non_empty_slices[np.around(sampled_indices).astype('int64')]
 
         # ensure you do not overshoot
-        slices_in_dim = [sn for sn in slices_in_dim if sn >= 0 or sn <= num_non_empty]
+        slices_in_dim = [sn for sn in slices_in_dim if
+                         sn >= 0 or sn <= num_non_empty]
         # adding view and slice # at the same time.
-        slices.extend([(view, slice) for slice in slices_in_dim])
+        slices.extend([(view, slice_) for slice_ in slices_in_dim])
 
     return slices
 
@@ -238,17 +249,19 @@ def check_event_in_axes(event, axes):
     # Axis.contains() method returns a tuple: Bool, Dict; so need [0] to capture Bool
     try:
         return any([ax.contains(event)[0] for ax in axes])
-    except TypeError: # when it is not a list/iterable of axes
+    except TypeError:  # when it is not a list/iterable of axes
         return axes.contains(event)[0]
     except:
         raise ValueError('Input must be a matplotlib Axis or an Iterable of Axes!')
 
 
-def check_layout(total_num_slices, num_views, num_rows_per_view, num_rows_for_surf_vis):
+def check_layout(total_num_slices, num_views, num_rows_per_view,
+                 num_rows_for_surf_vis):
     """Ensures all odd cases are dealt with"""
 
     num_cols = int(np.ceil(
-        total_num_slices / ((num_views * num_rows_per_view) + num_rows_for_surf_vis)))
+        total_num_slices / (
+            (num_views * num_rows_per_view) + num_rows_for_surf_vis)))
 
     return num_cols
 
@@ -408,7 +421,7 @@ def restore_previous_ratings(qcw):
     incomplete_list = list(qcw.id_list)
     prev_done = []  # empty list
 
-    ratings_file, backup_name_ratings = get_ratings_path_info(qcw)
+    ratings_file, _ = get_ratings_path_info(qcw)
 
     if pexists(ratings_file):
         ratings, notes = load_ratings_csv(ratings_file)
@@ -420,8 +433,7 @@ def restore_previous_ratings(qcw):
         notes = dict()
 
     if len(prev_done) > 0:
-        print('\nRatings for {}/{} subjects were restored.'.format(len(prev_done),
-                                                                   len(qcw.id_list)))
+        print(f'\nRestored {len(prev_done)}/{len(qcw.id_list)} previous ratings')
 
     if len(incomplete_list) < 1:
         print('No subjects to review/rate - exiting.')
@@ -490,7 +502,7 @@ def summarize_ratings(ratings_file, out_dir=None):
     import re
     clean = lambda lbl: re.sub(r'\W+', '_', lbl.lower())
 
-    rating_dict, notes = load_ratings_csv(ratings_file)
+    rating_dict, _ = load_ratings_csv(ratings_file)
 
     rating_list = list()
     uniq_labels = set()
@@ -512,7 +524,6 @@ def summarize_ratings(ratings_file, out_dir=None):
 
     counter = Counter(all_labels)
     print('Ratings summary\n  Counts (note some IDs can have multiple ratings):')
-    id_lists = dict()
     for label, count in counter.items():
         print('\t{lbl:>{mw}} : {cnt:>7}'.format(lbl=label, cnt=count, mw=max_width))
 
@@ -688,7 +699,8 @@ def freesurfer_vis_tool_installed():
 
     if os.getenv('FREESURFER_HOME') is None:
         print('the environment variable FREESURFER_HOME is not set!')
-        return False, None
+        # using freeview here instead of None to recognize existing visualizations
+        return False, "freeview"
 
     fv_callable = which('freeview') is not None
     if fv_callable:
@@ -886,8 +898,9 @@ def expand_regex_paths(in_dir, subject_id, req_file):
 def get_path_for_subject(in_dir, subject_id, req_file, vis_type, in_dir_type=None):
     """Constructs the path for the image file based on chosen input and vis type"""
 
-    if vis_type is not None and (
-        vis_type in freesurfer_vis_types or in_dir_type in ['freesurfer', ]):
+    if (vis_type is not None) and \
+        ((vis_type in freesurfer_vis_types) or
+         (in_dir_type in ['freesurfer', ])):
         out_path = get_freesurfer_mri_path(in_dir, subject_id, req_file)
     else:
         out_path = realpath(pjoin(in_dir, subject_id, req_file))
@@ -939,7 +952,7 @@ def check_outlier_params(method, fraction, feat_types, disable_outlier_detection
             ' '.format(type_of_features, cfg.avail_OLD_source_of_features))
 
     if type_of_features.lower() == 'freesurfer' and \
-        vis_type not in cfg.freesurfer_vis_types:
+            vis_type not in cfg.freesurfer_vis_types:
         raise NotImplementedError(
             'Outlier detection based on current vis_type is not implemented.'
             '\nAllowed visualization types: {}'.format(cfg.freesurfer_vis_types))
@@ -1007,6 +1020,17 @@ def check_labels(vis_type, label_set):
     return vis_type, label_set
 
 
+def check_slice_locations_percent(slice_loc):
+    """Checks they are numbers between 0 and 100 inclusive"""
+
+    slice_loc = [float(sl) for sl in slice_loc]
+    if any([sl < 1 or sl > 100 for sl in slice_loc]):
+        raise ValueError('One or more slice locations specified is invalid. '
+                         'They must be between 1 and 100.')
+
+    return slice_loc
+
+
 def check_views(views):
     """Checks which views were selected."""
 
@@ -1031,16 +1055,17 @@ def check_views(views):
 def check_string_is_nonempty(string, string_type='string'):
     """Ensures input is a string of non-zero length"""
 
-    if string is None or \
-        (not isinstance(string, str)) or \
-        len(string) < 1:
+    if (string is None) or \
+            (not isinstance(string, str)) or \
+            (len(string) < 1):
         raise ValueError('name of the {} must not be empty!'
                          ''.format(string_type))
 
     return string
 
 
-def check_inputs_defacing(in_dir, defaced_name, mri_name, render_name, id_list_in):
+def check_inputs_defacing(in_dir, defaced_name, mri_name, render_name, id_list_in,
+                          slice_loc):
     """Validates the integrity of the inputs"""
 
     in_dir = realpath(in_dir)
@@ -1051,6 +1076,8 @@ def check_inputs_defacing(in_dir, defaced_name, mri_name, render_name, id_list_i
     mri_name = check_string_is_nonempty(mri_name, 'original MRI scan')
     render_name = check_string_is_nonempty(render_name, '3D rendered image')
 
+    slice_loc = check_slice_locations_percent(slice_loc)
+
     if id_list_in is not None:
         if not pexists(id_list_in):
             raise IOError('Given ID list does not exist @ \n'
@@ -1116,7 +1143,7 @@ def check_inputs_defacing(in_dir, defaced_name, mri_name, render_name, id_list_i
     print('{} subjects are usable for review.'.format(len(id_list_out)))
 
     return in_dir, np.array(id_list_out), images_for_id, \
-           defaced_name, mri_name, render_name
+           defaced_name, mri_name, render_name, slice_loc
 
 
 def print_time_stamp():
